@@ -31,22 +31,22 @@ const sidebars = {
             id: 'configuration/providers/index',
           },
           items: [
-            'configuration/providers/google',
-            'configuration/providers/azure',
-            'configuration/providers/adfs',
-            'configuration/providers/facebook',
-            'configuration/providers/github',
-            'configuration/providers/gitea',
-            'configuration/providers/keycloak',
-            'configuration/providers/keycloak_oidc',
-            'configuration/providers/gitlab',
-            'configuration/providers/linkedin',
-            'configuration/providers/azure_ad',
-            'configuration/providers/openid_connect',
-            'configuration/providers/login_gov',
-            'configuration/providers/nextcloud',
-            'configuration/providers/digitalocean',
-            'configuration/providers/bitbucket',
+            "configuration/providers/adfs",
+            "configuration/providers/azure",
+            "configuration/providers/bitbucket",
+            "configuration/providers/digitalocean",
+            "configuration/providers/facebook",
+            "configuration/providers/gitea",
+            "configuration/providers/github",
+            "configuration/providers/gitlab",
+            "configuration/providers/google",
+            "configuration/providers/keycloak",
+            "configuration/providers/keycloak_oidc",
+            "configuration/providers/linkedin",
+            "configuration/providers/login_gov",
+            "configuration/providers/ms_entra_id",
+            "configuration/providers/nextcloud",
+            "configuration/providers/openid_connect",
           ],
         },
         'configuration/session_storage',
